import{C as p,_ as i}from"./View.vue_vue_type_script_setup_true_lang--epD_2rI.js";import{a as n,ak as s,b as m,f as a,u as d}from"./jwt-decode.esm-BUhVyVlz.js";import"./router--fZPWl_4.js";import"./ts.worker-tNVI-xkB.js";import"./fetch-A_NPc3-a.js";import"./record-DR9hKNcZ.js";import"./SaveButton-C089rTG9.js";import"./ExclamationCircleOutlined-DcGVLqfe.js";import"./CrudView-Dk-92GNs.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-BWS8VzUF.js";import"./constants-sXT52FXr.js";import"./url--41vRoge.js";import"./PhDotsThreeVertical.vue-CtaI-VTO.js";import"./index-B86kUNfN.js";import"./asyncComputed-yxL-_N40.js";import"./omniChatStore-CtPJT8zG.js";import"./contracts.generated-B7f_Fl9j.js";import"./runnerData-D-etV1KP.js";import"./colorHelpers-PI4QQo4l.js";import"./uuid-Co724qsj.js";import"./PhCopySimple.vue-DA1DwBfI.js";import"./PhPencil.vue-DdZnV3JU.js";import"./useCodebaseEvents-CUQu5RbS.js";import"./index-DUgET7yi.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="ca457382-3fb6-4755-b86d-ea7211046b8e",o._sentryDebugIdIdentifier="sentry-dbid-ca457382-3fb6-4755-b86d-ea7211046b8e")}catch{}})();const G=n({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(c,f)=>(a(),m(i,{"env-var-repository":d(e),mode:"console"},null,8,["env-var-repository"]))}});export{G as default};
//# sourceMappingURL=EnvVars-0N8oTu2n.js.map
