import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-B7pJiKDr.js";import{a as i,k as u,h as d,u as n,af as m,ak as l,f,aO as _}from"./jwt-decode.esm-BUhVyVlz.js";import{u as b}from"./workspaceStore-DvIMqk3J.js";import"./OTPInput-DCZtPrel.js";import"./Logo-c0WOaDFC.js";import"./string-DGCBHlx5.js";import"./CircularLoading-BuRh_i1k.js";import"./index-DUgET7yi.js";import"./userStore-BE74D4vD.js";import"./runnerData-D-etV1KP.js";import"./url--41vRoge.js";import"./colorHelpers-PI4QQo4l.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ba89c9c1-912b-4668-a429-2e56a2c20922",e._sentryDebugIdIdentifier="sentry-dbid-ba89c9c1-912b-4668-a429-2e56a2c20922")}catch{}})();const g={class:"runner"},y=i({__name:"Login",setup(e){const o=m(),a=l(),r=b(),c=async()=>{const{redirect:t,...s}=a.query;if(t){await o.push({path:t,query:s,params:a.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>(f(),u("div",g,[d(p,{"logo-url":n(r).state.workspace?.logoUrl??void 0,"brand-name":n(r).state.workspace?.brandName,locale:n(r).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=_(y,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-BdUGFlCS.js.map
