import{a as d,c as s,k as l,f as i,n as r,m as f,Q as c,K as a,aO as u}from"./jwt-decode.esm-BUhVyVlz.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="8182e355-6464-4eb6-9f7f-4def304c87e1",e._sentryDebugIdIdentifier="sentry-dbid-8182e355-6464-4eb6-9f7f-4def304c87e1")}catch{}})();const y=d({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean},flexLayout:{type:Boolean},innerPadding:{}},setup(e){const n=e,t=s(()=>({...n.innerPadding&&{padding:n.innerPadding}}));return(o,p)=>(i(),l("div",{class:a(["content-layout",{"no-padding":e.noPadding}])},[r("div",{class:a(["centered-layout",{"full-width":e.fullWidth,"flex-layout":e.flexLayout}]),style:c(t.value)},[f(o.$slots,"default",{},void 0,!0)],6)],2))}}),m=u(y,[["__scopeId","data-v-00e066e8"]]);export{m as C};
//# sourceMappingURL=ContentLayout-B3FTYpg-.js.map
