import{a as t,k as s,f as o,h as d,u as r,b8 as c,aO as i}from"./jwt-decode.esm-BUhVyVlz.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="ecae28ee-d7d8-419c-8ee8-1e901af30225",e._sentryDebugIdIdentifier="sentry-dbid-ecae28ee-d7d8-419c-8ee8-1e901af30225")}catch{}})();const f={class:"centered"},_=t({__name:"LoadingContainer",setup(e){return(n,a)=>(o(),s("div",f,[d(r(c))]))}}),u=i(_,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer-CCAnDFid.js.map
