const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-BPAHbVOf.js","assets/workspaceStore-DvIMqk3J.js","assets/jwt-decode.esm-BUhVyVlz.js","assets/jwt-decode-D9e-DIPp.css","assets/userStore-BE74D4vD.js","assets/runnerData-D-etV1KP.js","assets/url--41vRoge.js","assets/colorHelpers-PI4QQo4l.js","assets/OidcLogoutCallback-CbxWPPDi.js","assets/Login-BdUGFlCS.js","assets/Login.vue_vue_type_script_setup_true_lang-B7pJiKDr.js","assets/OTPInput-DCZtPrel.js","assets/OTPInput-DkitIIgo.css","assets/Logo-c0WOaDFC.js","assets/Logo-D2kepPyK.css","assets/string-DGCBHlx5.js","assets/CircularLoading-BuRh_i1k.js","assets/CircularLoading-BiyobKo3.css","assets/index-DUgET7yi.js","assets/Login-BYf3W3mQ.css","assets/Login-C1k-SC0u.css","assets/Main-BbQ1f-u-.js","assets/PlayerNavbar-tF5lzJW_.js","assets/metadata-c360vDlU.js","assets/PhMagnifyingGlass.vue-DtuapUq4.js","assets/PhWebhooksLogo.vue-DFik7_2H.js","assets/LoadingOutlined-CBUlerLh.js","assets/PhSignOut.vue-CG-3ks7V.js","assets/index-xoU6hRQn.js","assets/PlayerNavbar-VlEtzX8f.css","assets/Main-DqPmGmnC.css","assets/Home-ClnK3Xvv.js","assets/Watermark-CpWVuhyv.js","assets/constants-sXT52FXr.js","assets/Watermark-DMbnzHiR.css","assets/PhArrowSquareOut.vue-BO8SnTDi.js","assets/index-BdAu_anO.js","assets/Home-B6UGln4L.css","assets/Error-CwZkTMiv.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-BEiNlq3B.js","assets/logo-BiWG9_W5.js","assets/Error-CIbhyrKS.css","assets/Form-BoOrCZTL.js","assets/FormRunner-DuAGYfHv.js","assets/Steps-CRI1I7fm.js","assets/index-CCmPkIyA.js","assets/Steps-DqO_G9S3.css","assets/FormRunner-Fkp92u0R.css","assets/redirect-DjJGZwcA.js","assets/asyncComputed-yxL-_N40.js","assets/uuid-Co724qsj.js","assets/Form-CshGBPDC.css"])))=>i.map(i=>d[i]);
import{al as m,am as u,_ as t,an as l}from"./jwt-decode.esm-BUhVyVlz.js";import{u as p}from"./userStore-BE74D4vD.js";import{a as _}from"./workspaceStore-DvIMqk3J.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="618619fe-b555-409e-acf5-79bfb0c34f1c",e._sentryDebugIdIdentifier="sentry-dbid-618619fe-b555-409e-acf5-79bfb0c34f1c")}catch{}})();const E=async()=>{try{const e=await fetch("/_editor/api/workspace/version");return e.ok&&(await e.json()).version||"4781331e1373ed97bd76f50b551067c5537069e1"}catch(e){return console.error("Failed to fetch Abstra version:",e),"4781331e1373ed97bd76f50b551067c5537069e1"}},h=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-BPAHbVOf.js"),__vite__mapDeps([0,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-CbxWPPDi.js"),__vite__mapDeps([8,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-BdUGFlCS.js"),__vite__mapDeps([9,10,2,3,1,4,5,6,7,11,12,13,14,15,16,17,18,19,20])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-BbQ1f-u-.js"),__vite__mapDeps([21,22,4,2,3,1,5,6,7,23,24,25,26,27,28,29,30])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-ClnK3Xvv.js"),__vite__mapDeps([31,23,2,3,24,25,32,1,4,5,6,7,33,34,35,36,26,37])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-CwZkTMiv.js"),__vite__mapDeps([38,39,40,13,2,3,14,33,1,4,5,6,7,36,41])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-BoOrCZTL.js"),__vite__mapDeps([42,4,2,3,43,10,1,5,6,7,11,12,13,14,15,16,17,18,19,44,45,46,32,33,34,47,48,49,50,51])),meta:{hideLogin:!0}}]}],i=m({history:u("/"),routes:h,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),f=e=>async(a,o)=>{if(l(a,o),a.meta.allowUnauthenticated)return;const r=p();r.loadJWT();const s=await _(a.path),{redirect:c,...d}=a.query;switch(s.status){case"ALLOWED":break;case"UNAUTHORIZED":{const n=r.email;r.removeJWT(),await e.push({name:"playerLogin",query:{...d,redirect:c||a.path,reauth:n?"true":void 0,email:n||void 0},params:a.params});break}case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};i.beforeEach(f(i));export{h as a,f as b,E as g,i as r};
//# sourceMappingURL=router-OgMr6edg.js.map
