import{aT as r,aU as n,a9 as o,aV as c,aW as p,aX as d,aY as b,aZ as m,a_ as f,a$ as s,b0 as u,b1 as g,b2 as l}from"./jwt-decode.esm-BUhVyVlz.js";import{g as y,r as i}from"./router-OgMr6edg.js";import{b as w,s as _}from"./workspaceStore-DvIMqk3J.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang-CKZl1sLf.js";import"./userStore-BE74D4vD.js";import"./runnerData-D-etV1KP.js";import"./url--41vRoge.js";import"./colorHelpers-PI4QQo4l.js";import"./PlayerConfigProvider-DFP6gzgm.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="9756aa64-954b-43a5-8ba5-6c3dc62c0f1b",t._sentryDebugIdIdentifier="sentry-dbid-9756aa64-954b-43a5-8ba5-6c3dc62c0f1b")}catch{}})();class I{static init(){setInterval(()=>{w("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await _();const t=await y(),e=r(),a=n({render:()=>o(h)});c.init(),p(a,i,t),I.init(),a.use(i),a.use(e),a.use(d),a.mount("#app"),a.component("VSelect",b),a.component("Markdown",m),a.component("Message",f),s(a,u),s(a,g),s(a,l)})();
//# sourceMappingURL=player-Ra45kSVa.js.map
