import{i as h}from"./metadata-c360vDlU.js";import{W as b}from"./Watermark-CpWVuhyv.js";import{F as w}from"./PhArrowSquareOut.vue-BO8SnTDi.js";import{a as v,c as x,r as C,k as m,e as D,u as e,h as d,w as s,F as u,b as r,g as y,t as _,i as I,b3 as g,R as z,$ as F,af as B,f as a,K as L,Y as N,aO as S}from"./jwt-decode.esm-BUhVyVlz.js";import{u as T}from"./workspaceStore-DvIMqk3J.js";import{C as V}from"./index-BdAu_anO.js";import{L as W}from"./LoadingOutlined-CBUlerLh.js";import"./PhMagnifyingGlass.vue-DtuapUq4.js";import"./PhWebhooksLogo.vue-DFik7_2H.js";import"./constants-sXT52FXr.js";import"./userStore-BE74D4vD.js";import"./runnerData-D-etV1KP.js";import"./url--41vRoge.js";import"./colorHelpers-PI4QQo4l.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[n]="5faeffee-8961-40c6-a6fb-798d324ecbdb",o._sentryDebugIdIdentifier="sentry-dbid-5faeffee-8961-40c6-a6fb-798d324ecbdb")}catch{}})();const $={key:0,class:"home-container"},E=v({__name:"Home",setup(o){const n=B(),i=T(),p=x(()=>i.state.workspace?.sidebar.filter(c=>c.id!=="home")||[]),l=C(null),k=async(c,f)=>{l.value=f,await n.push({path:`/${c}`}),l.value=null};return(c,f)=>e(i).state.workspace?(a(),m("div",$,[d(e(u),{vertical:"",gap:"large",class:"cards-container"},{default:s(()=>[p.value.length===0?(a(),r(e(g),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:s(()=>[y(_(e(I).translate("i18n_home_no_forms_available")),1)]),_:1})):(a(!0),m(z,{key:1},F(p.value,t=>(a(),r(e(V),{key:t.id,class:L(["form-card",{loading:l.value===t.id}]),"body-style":{cursor:"pointer"},onClick:H=>k(t.path,t.id)},{default:s(()=>[d(e(u),{gap:"large",align:"center",justify:"space-between"},{default:s(()=>[(a(),r(N(e(h)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),d(e(g),{style:{"font-size":"18px","font-weight":"500"}},{default:s(()=>[y(_(t.name),1)]),_:2},1024),l.value!==t.id?(a(),r(e(w),{key:0,size:"20"})):(a(),r(e(W),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),d(b,{class:"watermark","page-id":"home",locale:e(i).state.workspace.language},null,8,["locale"])])):D("",!0)}}),Z=S(E,[["__scopeId","data-v-2dd12c4e"]]);export{Z as default};
//# sourceMappingURL=Home-ClnK3Xvv.js.map
