import{a as n,af as r,J as i,k as s,f as c,h as d,u as f,b8 as p,aO as u}from"./jwt-decode.esm-BUhVyVlz.js";import{u as l}from"./organizationSwitcher-BEVyUYF-.js";import"./router--fZPWl_4.js";import"./ts.worker-tNVI-xkB.js";import"./organization-7XaUn38z.js";import"./tables-Dl6wbkmy.js";import"./record-DR9hKNcZ.js";import"./string-DGCBHlx5.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[a]="551dfac9-8cf1-4fe9-9fa5-542d5e34e8fa",o._sentryDebugIdIdentifier="sentry-dbid-551dfac9-8cf1-4fe9-9fa5-542d5e34e8fa")}catch{}})();const m={class:"loading-container"},_=n({__name:"RootRedirector",setup(o){const a=l(),t=r();return i(async()=>{const e=await a.selectDefaultOrganization();e.name==="organization"&&e.params?.organizationId?window.location.href=`/organizations/${e.params.organizationId}`:e.name==="onboarding"?window.location.href="/onboarding":t.replace(e)}),(e,g)=>(c(),s("div",m,[d(f(p),{size:"large"})]))}}),k=u(_,[["__scopeId","data-v-a77ce5c1"]]);export{k as default};
//# sourceMappingURL=RootRedirector-BaOyJ4zz.js.map
