import{O as l}from"./workspaceStore-DvIMqk3J.js";import{a as c,J as u,k as f,h as o,w as n,u as t,ao as _,T as p,g as r,t as s,i,f as g}from"./jwt-decode.esm-BUhVyVlz.js";import"./userStore-BE74D4vD.js";import"./runnerData-D-etV1KP.js";import"./url--41vRoge.js";import"./colorHelpers-PI4QQo4l.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="31a99d0a-2700-4346-8970-9fd631e7ea3a",e._sentryDebugIdIdentifier="sentry-dbid-31a99d0a-2700-4346-8970-9fd631e7ea3a")}catch{}})();const D=c({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new l().logoutCallback()}),(a,d)=>(g(),f("div",null,[o(t(_),null,{default:n(()=>[r(s(t(i).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(t(p),null,{default:n(()=>[r(s(t(i).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLogoutCallback-CbxWPPDi.js.map
