import{aO as l,k as c,f as r,n as d,m as n,e as i,a as u,ak as f,b as _,u as t}from"./jwt-decode.esm-BUhVyVlz.js";import{O as p}from"./OmniChat-CuZUd9dI.js";import{u as m}from"./omniChatStore-CtPJT8zG.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="0c7179dd-a465-4e32-a310-6e3ef43d0ffb",e._sentryDebugIdIdentifier="sentry-dbid-0c7179dd-a465-4e32-a310-6e3ef43d0ffb")}catch{}})();const h={},y={class:"project-layout"},b={class:"project-navbar"},j={class:"project-body"},g={key:0,class:"project-sidebar"},k={class:"project-content"},I={key:1,class:"project-chat"};function v(e,s){return r(),c("div",y,[d("header",b,[n(e.$slots,"navbar",{},void 0,!0)]),d("section",j,[e.$slots.sidebar?(r(),c("aside",g,[n(e.$slots,"sidebar",{},void 0,!0)])):i("",!0),d("main",k,[n(e.$slots,"content",{},void 0,!0)]),e.$slots.chat?(r(),c("aside",I,[n(e.$slots,"chat",{},void 0,!0)])):i("",!0)])])}const D=l(h,[["render",v],["__scopeId","data-v-c0f68a2c"]]),S=u({__name:"ConsoleOmniChat",setup(e){const a=f().params.projectId,o=m();return o.init("console",a),(C,$)=>t(o).controller&&t(o).repository?(r(),_(p,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(a)},"show-console-suggestions":!0},null,8,["ai-chat-repository","controller","environment"])):i("",!0)}});export{D as P,S as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang-Hu9R0MEZ.js.map
