import{a as _,af as f,ak as m,i as n,b as p,f as c,w as b,k as g,R as y,$ as v,h as k,u as r,n as w,t as I}from"./jwt-decode.esm-BUhVyVlz.js";import{A as T,T as h}from"./index-BdAu_anO.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="243bc48b-5cf3-4c02-bb9d-0c7bc5c4df27",e._sentryDebugIdIdentifier="sentry-dbid-243bc48b-5cf3-4c02-bb9d-0c7bc5c4df27")}catch{}})();const N=_({__name:"TablesTabs",setup(e){const a=f(),t=m(),i=String(t.name),d=t.params.projectId,l=[{label:n.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:n.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:n.translate("i18n_tablestabs_run_sql"),value:"sql"}],u=o=>{a.push({name:String(o),params:{projectId:d}})};return(o,D)=>(c(),p(r(h),{"active-key":r(i),options:l,"onUpdate:activeKey":u},{default:b(()=>[(c(),g(y,null,v(l,s=>k(r(T),{key:s.value,name:s.value},{tab:b(()=>[w("span",null,I(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{N as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-erbLQtOn.js.map
