import{_ as m}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-BEiNlq3B.js";import{B as y}from"./BaseLayout-DZT6eyZR.js";import{a as l,W as _,a5 as b,aO as u,aK as v,aL as g,f,k as h,n as a,Q as s,J as w,af as S,b as k,w as n,ak as B,h as i,u as I}from"./jwt-decode.esm-BUhVyVlz.js";import{u as L}from"./editor-iocIi3O-.js";import{A as $}from"./index-CJOAJVlp.js";import"./logo-BiWG9_W5.js";import"./Logo-c0WOaDFC.js";import"./router-OgMr6edg.js";import"./userStore-BE74D4vD.js";import"./workspaceStore-DvIMqk3J.js";import"./runnerData-D-etV1KP.js";import"./url--41vRoge.js";import"./colorHelpers-PI4QQo4l.js";import"./useCodebaseEvents-CUQu5RbS.js";import"./contracts.generated-B7f_Fl9j.js";import"./ts.worker-tNVI-xkB.js";import"./constants-sXT52FXr.js";import"./linters-Bnff_kpO.js";import"./asyncComputed-yxL-_N40.js";import"./index-B86kUNfN.js";import"./index-xoU6hRQn.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="1d71b255-769a-4c1a-b74c-b2917c83b101",e._sentryDebugIdIdentifier="sentry-dbid-1d71b255-769a-4c1a-b74c-b2917c83b101")}catch{}})();const x=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),D={class:"v-spinner"};function K(e,r,o,c,d,p){return v((f(),h("div",D,[a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const P=u(x,[["render",K],["__scopeId","data-v-06538001"]]),R={class:"content"},z=l({__name:"ProjectLogin",setup(e){const r=B(),o=S(),c=L();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),o.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){o.push({name:"error"});return}await c.createLogin(t).then(d),o.push({name:"editor"})}),(t,A)=>(f(),k(y,null,{navbar:n(()=>[i(I($),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(m)]),_:1})]),content:n(()=>[a("div",R,[i(P)])]),_:1}))}}),re=u(z,[["__scopeId","data-v-d2a19803"]]);export{re as default};
//# sourceMappingURL=ProjectLogin-Cyqrmofu.js.map
