import{P as _}from"./PlayerNavbar-tF5lzJW_.js";import{a as g,ak as c,r as h,c as k,k as b,b as y,e as v,n as w,u as n,h as L,a8 as C,af as I,f as i,aO as N}from"./jwt-decode.esm-BUhVyVlz.js";import{u as V}from"./workspaceStore-DvIMqk3J.js";import"./userStore-BE74D4vD.js";import"./metadata-c360vDlU.js";import"./PhMagnifyingGlass.vue-DtuapUq4.js";import"./PhWebhooksLogo.vue-DFik7_2H.js";import"./LoadingOutlined-CBUlerLh.js";import"./PhSignOut.vue-CG-3ks7V.js";import"./index-xoU6hRQn.js";import"./runnerData-D-etV1KP.js";import"./url--41vRoge.js";import"./colorHelpers-PI4QQo4l.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="8dac81c7-c6d8-47fd-8ef2-3cfb5a549fb7",o._sentryDebugIdIdentifier="sentry-dbid-8dac81c7-c6d8-47fd-8ef2-3cfb5a549fb7")}catch{}})();const B={class:"main-container"},D={class:"content"},R=g({__name:"Main",setup(o){const e=I(),t=V(),d=c().path,a=h(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},f=k(()=>!!c().meta.hideLogin);return(r,s)=>{const m=C("RouterView");return i(),b("div",B,[n(t).state.workspace?(i(),y(_,{key:0,"current-path":n(d),"hide-login":f.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",D,[L(m)])])}}}),G=N(R,[["__scopeId","data-v-f095bece"]]);export{G as default};
//# sourceMappingURL=Main-BbQ1f-u-.js.map
