import{N as l}from"./Navbar-DCU6nSf8.js";import{B as f}from"./BaseLayout-DZT6eyZR.js";import{C as _}from"./ContentLayout-B3FTYpg-.js";import{a as b,ak as g,c as e,a8 as v,b as a,f as i,w as n,h as c,e as y}from"./jwt-decode.esm-BUhVyVlz.js";import{_ as w}from"./BillingAlert.vue_vue_type_script_setup_true_lang-CrCkY748.js";import{u as z}from"./projectsStore-CXtWnFQL.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-B-6Kt_bn.js";import"./constants-sXT52FXr.js";import"./PhTranslate.vue-DBVsQhi5.js";import"./PhPencilSimple.vue-BNriLgTa.js";import"./router--fZPWl_4.js";import"./ts.worker-tNVI-xkB.js";import"./organization-7XaUn38z.js";import"./project-0z4ss282.js";import"./record-DR9hKNcZ.js";import"./tables-Dl6wbkmy.js";import"./string-DGCBHlx5.js";import"./keyboard-DNDfOOO2.js";import"./os-CE7Hl5gG.js";import"./organizationSwitcher-BEVyUYF-.js";import"./folder-Da3hAD4e.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-38ABqf8y.js";import"./member-ChnqugLk.js";import"./index-Bg5_zFCB.js";import"./index-BdAu_anO.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-BFUox8Ip.js";import"./PhNotePencil.vue-MpmpkQ3e.js";import"./PhSignOut.vue-CG-3ks7V.js";import"./index-B86kUNfN.js";import"./index-xoU6hRQn.js";import"./PhPlus.vue-DBBJFuju.js";import"./omniChatStore-CtPJT8zG.js";import"./contracts.generated-B7f_Fl9j.js";import"./runnerData-D-etV1KP.js";import"./url--41vRoge.js";import"./colorHelpers-PI4QQo4l.js";import"./uuid-Co724qsj.js";import"./PhCopySimple.vue-DA1DwBfI.js";import"./index-CJOAJVlp.js";import"./index-DUgET7yi.js";import"./ant-design-CVO0Y7Qj.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="a01a50a7-e779-431e-844e-e5eb54dbc424",t._sentryDebugIdIdentifier="sentry-dbid-a01a50a7-e779-431e-844e-e5eb54dbc424")}catch{}})();const ut=b({__name:"Organization",setup(t){const o=g(),p=z(),m=e(()=>o.params.organizationId),r=e(()=>p.fetchedState?.organization),d=e(()=>r.value?{organizationId:r.value.id}:void 0),s=e(()=>r.value?.billingMetadata);return(I,k)=>{const u=v("RouterView");return i(),a(f,null,{navbar:n(()=>[c(l,{"use-cascader":!0,"cascader-props":d.value},null,8,["cascader-props"])]),content:n(()=>[c(_,null,{default:n(()=>[s.value?(i(),a(w,{key:0,"billing-metadata":s.value,"organization-id":m.value},null,8,["billing-metadata","organization-id"])):y("",!0),(i(),a(u,{key:m.value}))]),_:1})]),_:1})}}});export{ut as default};
//# sourceMappingURL=Organization-F80OFHgD.js.map
