import{L as f}from"./CircularLoading-BuRh_i1k.js";import{a as u,ak as p,J as h,k as _,f as l,n as d,h as g,aO as m}from"./jwt-decode.esm-BUhVyVlz.js";import{E as a,a as y}from"./router--fZPWl_4.js";import"./ts.worker-tNVI-xkB.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="58e512a7-49c7-44cb-a6f4-ff94bcbcbe31",e._sentryDebugIdIdentifier="sentry-dbid-58e512a7-49c7-44cb-a6f4-ff94bcbcbe31")}catch{}})();const b={class:"authorize"},w={class:"content"},A=u({__name:"Authorize",setup(e){const o=p();return h(()=>{const{client_id:r,redirect_uri:s,response_type:n,state:i}=o.query,t=a.cloudApi.startsWith("https://")||a.cloudApi.startsWith("http://")?new URL(`${a.cloudApi}/oauth/authorize`):new URL(`${location.origin}${a.cloudApi}/oauth/authorize`);typeof r=="string"&&t.searchParams.set("client_id",r),typeof s=="string"&&t.searchParams.set("redirect_uri",s),typeof n=="string"&&t.searchParams.set("response_type",n),typeof i=="string"&&t.searchParams.set("state",i);const c=y.getAuthor();c?.jwt&&t.searchParams.set("session_token",c.jwt),window.location.href=t.toString()}),(r,s)=>(l(),_("div",b,[d("div",w,[s[0]||(s[0]=d("h1",null,"Authorizing...",-1)),g(f)])]))}}),L=m(A,[["__scopeId","data-v-57fe5408"]]);export{L as default};
//# sourceMappingURL=Authorize-CJ7MbH91.js.map
